@@ -29,9 +29,9 @@
 
 // KDE includes.
 
-#include <kconfig.h>
-#include <klocale.h>
-#include <kapplication.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 
 // LibKDcraw includes.
@@ -131,7 +131,7 @@ public:
 
     TQStringList                          albumCollectionNames;
 
-    KConfig                             *config;
+    TDEConfig                             *config;
 
     AlbumSettings::AlbumSortOrder        albumSortOrder;
     AlbumSettings::ImageSortOrder        imageSortOrder;
@@ -258,7 +258,7 @@ void AlbumSettings::init()
 
 void AlbumSettings::readSettings()
 {
-    KConfig* config = d->config;
+    TDEConfig* config = d->config;
 
     // ---------------------------------------------------------------------
 
@@ -366,7 +366,7 @@ void AlbumSettings::readSettings()
 
 void AlbumSettings::saveSettings()
 {
-    KConfig* config = d->config;
+    TDEConfig* config = d->config;
 
     // ---------------------------------------------------------------------
 
