@@ -35,7 +35,7 @@
 // KDE includes.
 
 #include <kdialogbase.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kservice.h>
 #include <krun.h>
 #include <ktrader.h>
@@ -45,7 +45,7 @@
 #include <kdatetbl.h>
 #include <kiconloader.h>
 #include <kprocess.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 // LibKipi includes.
 
@@ -110,7 +110,7 @@ public:
 
     TQToolButton       *cornerButton;
 
-    KPopupFrame       *panIconPopup;
+    TDEPopupFrame       *panIconPopup;
 
     PanIconWidget     *panIconWidget;
 
@@ -131,8 +131,8 @@ ImagePreviewView::ImagePreviewView(AlbumWidgetStack *parent)
     d->parent = parent;
 
     // get preview size from screen size, but limit from VGA to WQXGA
-    d->previewSize = TQMAX(KApplication::desktop()->height(),
-                          KApplication::desktop()->width());
+    d->previewSize = TQMAX(TDEApplication::desktop()->height(),
+                          TDEApplication::desktop()->width());
     if (d->previewSize < 640)
         d->previewSize = 640;
     if (d->previewSize > 2560)
@@ -342,18 +342,18 @@ void ImagePreviewView::slotContextMenu()
     KMimeType::Ptr mimePtr = KMimeType::findByURL(url, 0, true, true);
 
     TQValueVector<KService::Ptr> serviceVector;
-    KTrader::OfferList offers = KTrader::self()->query(mimePtr->name(), "Type == 'Application'");
+    TDETrader::OfferList offers = TDETrader::self()->query(mimePtr->name(), "Type == 'Application'");
 
     TQPopupMenu openWithMenu;
 
-    KTrader::OfferList::Iterator iter;
+    TDETrader::OfferList::Iterator iter;
     KService::Ptr ptr;
     int index = 100;
 
     for( iter = offers.begin(); iter != offers.end(); ++iter )
     {
         ptr = *iter;
-        openWithMenu.insertItem( ptr->pixmap(KIcon::Small), ptr->name(), index++);
+        openWithMenu.insertItem( ptr->pixmap(TDEIcon::Small), ptr->name(), index++);
         serviceVector.push_back(ptr);
     }
 
@@ -390,12 +390,12 @@ void ImagePreviewView::slotContextMenu()
         {
             DDebug() << "Found JPEGLossless plugin" << endl;
 
-            KActionPtrList actionList = plugin->actions();
+            TDEActionPtrList actionList = plugin->actions();
 
-            for (KActionPtrList::const_iterator iter = actionList.begin();
+            for (TDEActionPtrList::const_iterator iter = actionList.begin();
                 iter != actionList.end(); ++iter)
             {
-                KAction* action = *iter;
+                TDEAction* action = *iter;
 
                 if (TQString::fromLatin1(action->name())
                     == TQString::fromLatin1("jpeglossless_rotate"))
@@ -562,7 +562,7 @@ void ImagePreviewView::slotCornerButtonPressed()
         d->panIconPopup = 0;
     }
 
-    d->panIconPopup    = new KPopupFrame(this);
+    d->panIconPopup    = new TDEPopupFrame(this);
     PanIconWidget *pan = new PanIconWidget(d->panIconPopup);
     pan->setImage(180, 120, getImage());
     d->panIconPopup->setMainWidget(pan);
