@@ -47,19 +47,19 @@
 
 // KDE includes.
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knuminput.h>
-#include <kmessagebox.h>
-#include <kselect.h>
-#include <kfiledialog.h>
-#include <kglobalsettings.h>
-#include <kaboutdata.h>
+#include <tdemessagebox.h>
+#include <tdeselect.h>
+#include <tdefiledialog.h>
+#include <tdeglobalsettings.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kpopupmenu.h>
+#include <tdeapplication.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 
 // Local includes.
@@ -98,11 +98,11 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
 
     // About data and help button.
 
-    KAboutData* about = new KAboutData("digikam",
+    TDEAboutData* about = new TDEAboutData("digikam",
                                        I18N_NOOP("Adjust Color Levels"),
                                        digikam_version,
                                        I18N_NOOP("An image-histogram-levels adjustment plugin for digiKam."),
-                                       KAboutData::License_GPL,
+                                       TDEAboutData::License_GPL,
                                        "(c) 2004-2008, Gilles Caulier",
                                        0,
                                        "http://www.digikam.org");
@@ -155,16 +155,16 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
     TQPushButton *linHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);
 
@@ -188,7 +188,7 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
 
     // -------------------------------------------------------------
     
-    m_hGradientMinInput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
+    m_hGradientMinInput = new KGradientSelector( TDESelector::Horizontal, gboxSettings );
     m_hGradientMinInput->setFixedHeight( 20 );
     m_hGradientMinInput->setMinValue(0);
     m_hGradientMinInput->setMaxValue(m_histoSegments);
@@ -197,7 +197,7 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
     m_hGradientMinInput->setColors( TQColor( "black" ), TQColor( "white" ) );
     m_hGradientMinInput->installEventFilter(this);
 
-    m_hGradientMaxInput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
+    m_hGradientMaxInput = new KGradientSelector( TDESelector::Horizontal, gboxSettings );
     m_hGradientMaxInput->setFixedHeight( 20 );
     m_hGradientMaxInput->setMinValue(0);
     m_hGradientMaxInput->setMaxValue(m_histoSegments);
@@ -223,7 +223,7 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
     TQToolTip::add( m_maxInput, i18n( "Maximal intensity input." ) );
     TQWhatsThis::add( m_maxInput, i18n("<p>Select the maximal intensity input value of the histogram."));
 
-    m_hGradientMinOutput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
+    m_hGradientMinOutput = new KGradientSelector( TDESelector::Horizontal, gboxSettings );
     m_hGradientMinOutput->setColors( TQColor( "black" ), TQColor( "white" ) );
     TQWhatsThis::add( m_hGradientMinOutput, i18n("<p>Select the minimal intensity output value of the histogram."));    
     TQToolTip::add( m_hGradientMinOutput, i18n( "Minimal intensity output." ) );
@@ -232,7 +232,7 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
     m_hGradientMinOutput->setMaxValue(m_histoSegments);
     m_hGradientMinOutput->installEventFilter(this);
     
-    m_hGradientMaxOutput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
+    m_hGradientMaxOutput = new KGradientSelector( TDESelector::Horizontal, gboxSettings );
     m_hGradientMaxOutput->setColors( TQColor( "black" ), TQColor( "white" ) );
     TQWhatsThis::add( m_hGradientMaxOutput, i18n("<p>Select the maximal intensity output value of the histogram."));
     TQToolTip::add( m_hGradientMaxOutput, i18n( "Maximal intensity output." ) );
@@ -256,9 +256,9 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
     m_pickerColorButtonGroup = new TQHButtonGroup(gboxSettings);
     m_pickBlack = new TQPushButton(m_pickerColorButtonGroup);
     m_pickerColorButtonGroup->insert(m_pickBlack, BlackTonal);
-    KGlobal::dirs()->addResourceType("color-picker-black", KGlobal::dirs()->kde_default("data") +
+    TDEGlobal::dirs()->addResourceType("color-picker-black", TDEGlobal::dirs()->kde_default("data") +
                                      "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("color-picker-black", "color-picker-black.png");
+    directory = TDEGlobal::dirs()->findResourceDir("color-picker-black", "color-picker-black.png");
     m_pickBlack->setPixmap( TQPixmap( directory + "color-picker-black.png" ) );
     m_pickBlack->setToggleButton(true);
     TQToolTip::add( m_pickBlack, i18n( "All channels shadow tone color picker" ) );
@@ -266,9 +266,9 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
                                        "levels input on Red, Green, Blue, and Luminosity channels."));
     m_pickGray  = new TQPushButton(m_pickerColorButtonGroup);
     m_pickerColorButtonGroup->insert(m_pickGray, GrayTonal);
-    KGlobal::dirs()->addResourceType("color-picker-gray", KGlobal::dirs()->kde_default("data") +
+    TDEGlobal::dirs()->addResourceType("color-picker-gray", TDEGlobal::dirs()->kde_default("data") +
                                      "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("color-picker-gray", "color-picker-gray.png");
+    directory = TDEGlobal::dirs()->findResourceDir("color-picker-gray", "color-picker-gray.png");
     m_pickGray->setPixmap( TQPixmap( directory + "color-picker-gray.png" ) );
     m_pickGray->setToggleButton(true);
     TQToolTip::add( m_pickGray, i18n( "All channels middle tone color picker" ) );
@@ -276,9 +276,9 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
                                       "levels input on Red, Green, Blue, and Luminosity channels."));
     m_pickWhite = new TQPushButton(m_pickerColorButtonGroup);
     m_pickerColorButtonGroup->insert(m_pickWhite, WhiteTonal);
-    KGlobal::dirs()->addResourceType("color-picker-white", KGlobal::dirs()->kde_default("data") +
+    TDEGlobal::dirs()->addResourceType("color-picker-white", TDEGlobal::dirs()->kde_default("data") +
                                      "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("color-picker-white", "color-picker-white.png");
+    directory = TDEGlobal::dirs()->findResourceDir("color-picker-white", "color-picker-white.png");
     m_pickWhite->setPixmap( TQPixmap( directory + "color-picker-white.png" ) );
     m_pickWhite->setToggleButton(true);
     TQToolTip::add( m_pickWhite, i18n( "All channels highlight tone color picker" ) );
@@ -288,12 +288,12 @@ AdjustLevelDialog::AdjustLevelDialog(TQWidget* parent)
     m_pickerColorButtonGroup->setFrameShape(TQFrame::NoFrame);    
 
     m_autoButton = new TQPushButton(gboxSettings);
-    m_autoButton->setPixmap(kapp->iconLoader()->loadIcon("run", (KIcon::Group)KIcon::Toolbar));    TQToolTip::add( m_autoButton, i18n( "Adjust all levels automatically." ) );
+    m_autoButton->setPixmap(kapp->iconLoader()->loadIcon("system-run", (TDEIcon::Group)TDEIcon::Toolbar));    TQToolTip::add( m_autoButton, i18n( "Adjust all levels automatically." ) );
     TQWhatsThis::add( m_autoButton, i18n("<p>If you press this button, all channel levels will be adjusted "
                                         "automatically."));
 
     m_resetButton = new TQPushButton(i18n("&Reset"), gboxSettings);
-    m_resetButton->setPixmap(kapp->iconLoader()->loadIcon("reload_page", (KIcon::Group)KIcon::Toolbar));     
+    m_resetButton->setPixmap(kapp->iconLoader()->loadIcon("reload_page", (TDEIcon::Group)TDEIcon::Toolbar));     
     TQToolTip::add( m_resetButton, i18n( "Reset current channel levels' values." ) );
     TQWhatsThis::add( m_resetButton, i18n("<p>If you press this button, all levels' values "
                                          "from the current selected channel "
@@ -690,7 +690,7 @@ void AdjustLevelDialog::slotScaleChanged(int scale)
 
 void AdjustLevelDialog::readUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("adjustlevels Tool Dialog");
 
     m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0));    // Luminosity.
@@ -728,7 +728,7 @@ void AdjustLevelDialog::readUserSettings()
 
 void AdjustLevelDialog::writeUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("adjustlevels Tool Dialog");
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
     config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
@@ -768,7 +768,7 @@ void AdjustLevelDialog::slotUser3()
 {
     KURL loadLevelsFile;
 
-    loadLevelsFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    loadLevelsFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                              TQString( "*" ), this,
                                              TQString( i18n("Select Gimp Levels File to Load")) );
     if( loadLevelsFile.isEmpty() )
@@ -789,7 +789,7 @@ void AdjustLevelDialog::slotUser2()
 {
     KURL saveLevelsFile;
 
-    saveLevelsFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    saveLevelsFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                              TQString( "*" ), this,
                                              TQString( i18n("Gimp Levels File to Save")) );
     if( saveLevelsFile.isEmpty() )
