@@ -39,15 +39,15 @@
 
 // KDE includes.
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <knuminput.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcursor.h>
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kpopupmenu.h>
+#include <tdeapplication.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 
 // Local includes.
@@ -77,11 +77,11 @@ ImageEffect_ColorFX::ImageEffect_ColorFX(TQWidget* parent)
 
     // About data and help button.
 
-    KAboutData *about = new KAboutData("digikam",
+    TDEAboutData *about = new TDEAboutData("digikam",
                             I18N_NOOP("Color Effects"),
                             digikam_version,
                             I18N_NOOP("A digiKam plugin to apply special color effects to an image."),
-                            KAboutData::License_GPL,
+                            TDEAboutData::License_GPL,
                             "(c) 2004-2005, Renchi Raju\n(c) 2006-2008, Gilles Caulier",
                             0,
                             "http://www.digikam.org");
@@ -131,16 +131,16 @@ ImageEffect_ColorFX::ImageEffect_ColorFX(TQWidget* parent)
     TQPushButton *linHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
     
     TQPushButton *logHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);       
 
@@ -242,7 +242,7 @@ ImageEffect_ColorFX::~ImageEffect_ColorFX()
 
 void ImageEffect_ColorFX::readUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("coloreffect Tool Dialog");
     m_effectType->setCurrentItem(config->readNumEntry("EffectType", ColorFX));
     m_levelInput->setValue(config->readNumEntry("LevelAjustment", 0));
@@ -252,7 +252,7 @@ void ImageEffect_ColorFX::readUserSettings()
 
 void ImageEffect_ColorFX::writeUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("coloreffect Tool Dialog");
     config->writeEntry("EffectType", m_effectType->currentItem());
     config->writeEntry("LevelAjustment", m_levelInput->value());
