@@ -47,15 +47,15 @@
 
 // KDE includes.
 
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
-#include <kfile.h>
-#include <kfiledialog.h>
-#include <kglobalsettings.h>
+#include <tdefile.h>
+#include <tdefiledialog.h>
+#include <tdeglobalsettings.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <ksqueezedtextlabel.h>
 #include <kstandarddirs.h>
 #include <ktabwidget.h>
@@ -153,16 +153,16 @@ ICCProofTool::ICCProofTool(TQObject* parent)
     TQPushButton *linHistoButton = new TQPushButton(m_scaleBG);
     TQToolTip::add(linHistoButton, i18n("<p>Linear"));
     m_scaleBG->insert(linHistoButton, HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap(TQPixmap(directory + "histogram-lin.png"));
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton(m_scaleBG);
     TQToolTip::add(logHistoButton, i18n("<p>Logarithmic"));
     m_scaleBG->insert(logHistoButton, HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap(TQPixmap(directory + "histogram-log.png"));
     logHistoButton->setToggleButton(true);
 
@@ -270,8 +270,8 @@ ICCProofTool::ICCProofTool(TQObject* parent)
     lcmsLogoLabel->setAlignment(AlignTop | AlignRight);
     lcmsLogoLabel->setText(TQString());
     lcmsLogoLabel->setURL("http://www.littlecms.com");
-    KGlobal::dirs()->addResourceType("logo-lcms", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("logo-lcms", "logo-lcms.png");
+    TDEGlobal::dirs()->addResourceType("logo-lcms", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("logo-lcms", "logo-lcms.png");
     lcmsLogoLabel->setPixmap(TQPixmap(directory + "logo-lcms.png"));
     TQToolTip::add(lcmsLogoLabel, i18n("Visit Little CMS project website"));
 
@@ -286,7 +286,7 @@ ICCProofTool::ICCProofTool(TQObject* parent)
 
     //---------- "Input" Page Setup ----------------------------------
 
-    m_toolBoxWidgets->insertItem(INPUTPAGE, inProfiles, SmallIconSet("camera"), i18n("Input Profile"));
+    m_toolBoxWidgets->insertItem(INPUTPAGE, inProfiles, SmallIconSet("camera-photo"), i18n("Input Profile"));
     TQWhatsThis::add(inProfiles, i18n("<p>Set here all parameters relevant of Input Color "
                     "Profiles.</p>"));
 
@@ -336,7 +336,7 @@ ICCProofTool::ICCProofTool(TQObject* parent)
     //---------- "Workspace" Page Setup ---------------------------------
 
     m_toolBoxWidgets->insertItem(WORKSPACEPAGE, spaceProfiles,
-                                 SmallIconSet("tablet"), i18n("Workspace Profile"));
+                                 SmallIconSet("input-tablet"), i18n("Workspace Profile"));
     TQWhatsThis::add(spaceProfiles, i18n("<p>Set here all parameters relevant to Color Workspace "
                     "Profiles.</p>"));
 
@@ -370,7 +370,7 @@ ICCProofTool::ICCProofTool(TQObject* parent)
     //---------- "Proofing" Page Setup ---------------------------------
 
     m_toolBoxWidgets->insertItem(PROOFINGPAGE, proofProfiles,
-                                 SmallIconSet("printer1"), i18n("Proofing Profile"));
+                                 SmallIconSet("printer"), i18n("Proofing Profile"));
     TQWhatsThis::add(proofProfiles, i18n("<p>Set here all parameters relevant to Proofing Color "
                     "Profiles.</p>"));
 
@@ -537,8 +537,8 @@ ICCProofTool::~ICCProofTool()
 
 void ICCProofTool::readSettings()
 {
-    TQString defaultICCPath = KGlobalSettings::documentPath();
-    KConfig* config        = kapp->config();
+    TQString defaultICCPath = TDEGlobalSettings::documentPath();
+    TDEConfig* config        = kapp->config();
 
     // General settings of digiKam Color Management
     config->setGroup("Color Management");
@@ -615,7 +615,7 @@ void ICCProofTool::readSettings()
 
 void ICCProofTool::writeSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("colormanagement Tool");
     config->writeEntry("Settings Tab", m_toolBoxWidgets->currentIndex());
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
@@ -652,7 +652,7 @@ void ICCProofTool::writeSettings()
 
 void ICCProofTool::processLCMSURL(const TQString& url)
 {
-    KApplication::kApplication()->invokeBrowser(url);
+    TDEApplication::kApplication()->invokeBrowser(url);
 }
 
 void ICCProofTool::slotSpotColorChanged(const DColor &color)
@@ -1186,7 +1186,7 @@ bool ICCProofTool::useDefaultProofProfile()
 
 void ICCProofTool::slotLoadSettings()
 {
-    KURL loadColorManagementFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadColorManagementFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                                            TQString("*"), kapp->activeWindow(),
                                                            TQString(i18n("Color Management Settings File to Load")));
     if (loadColorManagementFile.isEmpty())
@@ -1263,7 +1263,7 @@ void ICCProofTool::slotLoadSettings()
 
 void ICCProofTool::slotSaveAsSettings()
 {
-    KURL saveColorManagementFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveColorManagementFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                                 TQString( "*" ), kapp->activeWindow(),
                                                 TQString(i18n("Color Management Settings File to Save")));
     if (saveColorManagementFile.isEmpty())
