@@ -42,14 +42,14 @@
 
 // KDE includes.
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcharsets.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdialog.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <klistbox.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
+#include <tdelistbox.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 #include <kstandarddirs.h>
 #include <tqlineedit.h>
@@ -186,7 +186,7 @@ FontChooserWidget::FontChooserWidget(TQWidget *parent, const char *name,
 
     // Now create the actual boxes that hold the info
 
-    familyListBox = new KListBox( page, "familyListBox");
+    familyListBox = new TDEListBox( page, "familyListBox");
     familyListBox->setEnabled( !diff );
     gridLayout->addWidget( familyListBox, row, 0 );
     TQString fontFamilyWhatsThisText = i18n("Here you can choose the font family to be used." );
@@ -207,7 +207,7 @@ FontChooserWidget::FontChooserWidget(TQWidget *parent, const char *name,
 
     familyListBox->setMinimumHeight( minimumListHeight( familyListBox, visibleListSize  ) );
 
-    styleListBox = new KListBox( page, "styleListBox");
+    styleListBox = new TDEListBox( page, "styleListBox");
     styleListBox->setEnabled( !diff );
     gridLayout->addWidget(styleListBox, row, 1);
     TQString fontStyleWhatsThisText = i18n("Here you can choose the font style to be used." );
@@ -223,7 +223,7 @@ FontChooserWidget::FontChooserWidget(TQWidget *parent, const char *name,
     connect(styleListBox, TQT_SIGNAL(highlighted(const TQString &)),
             this, TQT_SLOT(style_chosen_slot(const TQString &)));
 
-    sizeListBox = new KListBox( page, "sizeListBox");
+    sizeListBox = new TDEListBox( page, "sizeListBox");
     sizeOfFont = new KIntNumInput( page, "sizeOfFont");
     sizeOfFont->setMinValue(4);
 
@@ -294,14 +294,14 @@ FontChooserWidget::FontChooserWidget(TQWidget *parent, const char *name,
     vbox->addWidget( xlfdEdit );
 
     // lets initialize the display if possible
-    setFont( KGlobalSettings::generalFont(), usingFixed );
+    setFont( TDEGlobalSettings::generalFont(), usingFixed );
 
     // check or uncheck or gray out the "relative" checkbox
     if( sizeIsRelativeState && sizeIsRelativeCheckBox )
         setSizeIsRelative( *sizeIsRelativeState );
 
-    KConfig *config = KGlobal::config();
-    KConfigGroupSaver saver(config, TQString::fromLatin1("General"));
+    TDEConfig *config = TDEGlobal::config();
+    TDEConfigGroupSaver saver(config, TQString::fromLatin1("General"));
     showXLFDArea(config->readBoolEntry(TQString::fromLatin1("fontSelectorShowXLFD"), false));
 }
 
