@@ -44,20 +44,20 @@
 // KDE includes.
 
 #include <kcursor.h>
-#include <klocale.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kpopupmenu.h>
+#include <tdeapplication.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 #include <kprogress.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
-#include <kglobalsettings.h>
-#include <kfiledialog.h>
+#include <tdeglobalsettings.h>
+#include <tdefiledialog.h>
 #include <kseparator.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kactivelabel.h>
 
 // Local includes.
@@ -91,11 +91,11 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(TQWidget* parent)
 
     // About data and help button.
 
-    KAboutData* about = new KAboutData("digikam",
+    TDEAboutData* about = new TDEAboutData("digikam",
                                        I18N_NOOP("White Color Balance Correction"), 
                                        digikam_version,
                                        I18N_NOOP("A digiKam image plugin to correct white color balance."),
-                                       KAboutData::License_GPL,
+                                       TDEAboutData::License_GPL,
                                        "(c) 2005-2008, Gilles Caulier", 
                                        0,
                                        "http://wwww.digikam.org");
@@ -148,16 +148,16 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(TQWidget* parent)
     TQPushButton *linHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);
 
@@ -229,8 +229,8 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(TQWidget* parent)
                                                  "<b>Daylight D65</b>: overcast sky light (6500K).<p>"
                                                  "<b>None</b>: no preset value."));
     m_pickTemperature = new TQPushButton(gboxSettings);
-    KGlobal::dirs()->addResourceType("color-picker-grey", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("color-picker-grey", "color-picker-grey.png");
+    TDEGlobal::dirs()->addResourceType("color-picker-grey", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("color-picker-grey", "color-picker-grey.png");
     m_pickTemperature->setPixmap( TQPixmap( directory + "color-picker-grey.png" ) );
     m_pickTemperature->setToggleButton(true);
     TQToolTip::add( m_pickTemperature, i18n( "Temperature tone color picker." ) );
@@ -281,7 +281,7 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(TQWidget* parent)
                                                  " (E.V): </qt>"), gboxSettings);
     m_mainExposureLabel  = new TQLabel(i18n("Main:"), gboxSettings);
     m_autoAdjustExposure = new TQPushButton(gboxSettings);
-    m_autoAdjustExposure->setPixmap(kapp->iconLoader()->loadIcon("run", (KIcon::Group)KIcon::Toolbar));
+    m_autoAdjustExposure->setPixmap(kapp->iconLoader()->loadIcon("system-run", (TDEIcon::Group)TDEIcon::Toolbar));
     TQToolTip::add( m_autoAdjustExposure, i18n( "Auto exposure adjustments" ) );
     TQWhatsThis::add( m_autoAdjustExposure, i18n("<p>With this button, you can automatically adjust Exposure "
                                                 "and Black Point values."));
@@ -729,7 +729,7 @@ void ImageEffect_WhiteBalance::resetValues()
 
 void ImageEffect_WhiteBalance::readUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("whitebalance Tool Dialog");
     m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0));    // Luminosity.
     m_scaleBG->setButton(config->readNumEntry("Histogram Scale", Digikam::HistogramWidget::LogScaleHistogram));
@@ -749,7 +749,7 @@ void ImageEffect_WhiteBalance::readUserSettings()
 
 void ImageEffect_WhiteBalance::writeUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("whitebalance Tool Dialog");
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
     config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
@@ -768,7 +768,7 @@ void ImageEffect_WhiteBalance::writeUserSettings()
 // Load all settings.
 void ImageEffect_WhiteBalance::slotUser3()
 {
-    KURL loadWhiteBalanceFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadWhiteBalanceFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                              TQString( "*" ), this,
                                              TQString( i18n("White Color Balance Settings File to Load")) );
     if( loadWhiteBalanceFile.isEmpty() )
@@ -811,7 +811,7 @@ void ImageEffect_WhiteBalance::slotUser3()
 // Save all settings.
 void ImageEffect_WhiteBalance::slotUser2()
 {
-    KURL saveWhiteBalanceFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveWhiteBalanceFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                              TQString( "*" ), this,
                                              TQString( i18n("White Color Balance Settings File to Save")) );
     if( saveWhiteBalanceFile.isEmpty() )
