@@ -100,7 +100,7 @@ bool JP2KLoader::load(const TQString& filePath, DImgLoaderObserver *observer)
     // -------------------------------------------------------------------
     // Initialize JPEG 2000 API.
 
-    register long  i, x, y;
+    long  i, x, y;
     int            components[4];
     unsigned int   maximum_component_depth, scale[4], x_step[4], y_step[4];
     unsigned long  number_components;
@@ -468,7 +468,7 @@ bool JP2KLoader::save(const TQString& filePath, DImgLoaderObserver *observer)
     // -------------------------------------------------------------------
     // Initialize JPEG 2000 API.
 
-    register long  i, x, y;
+    long  i, x, y;
     unsigned long  number_components;
 
     jas_image_t          *jp2_image   = 0;
