@@ -26,7 +26,7 @@
 
 // KDE includes.
 
-#include <kaction.h>
+#include <tdeaction.h>
 
 // Local includes.
 
@@ -35,10 +35,10 @@
 namespace Digikam 
 {
 
-class DIGIKAM_EXPORT DLogoAction : public KAction
+class DIGIKAM_EXPORT DLogoAction : public TDEAction
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     
