@@ -38,7 +38,7 @@
 
 #include <kstandarddirs.h>
 #include <kcursor.h>
-#include <kglobal.h> 
+#include <tdeglobal.h> 
 
 // Local includes.
 
