@@ -38,12 +38,12 @@
 // KDE includes.
 
 #include <kdialog.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcursor.h>
 #include <kprogress.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kstandarddirs.h>
 #include <kseparator.h>
 
@@ -152,8 +152,8 @@ ImagePannelWidget::ImagePannelWidget(uint w, uint h, const TQString& settingsSec
     {
        TQPushButton *duplicateHorButton = new TQPushButton( d->separateView );
        d->separateView->insert(duplicateHorButton, ImageRegionWidget::SeparateViewDuplicateHorz);
-       KGlobal::dirs()->addResourceType("duplicatebothhorz", KGlobal::dirs()->kde_default("data") + "digikam/data");
-       directory = KGlobal::dirs()->findResourceDir("duplicatebothhorz", "duplicatebothhorz.png");
+       TDEGlobal::dirs()->addResourceType("duplicatebothhorz", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+       directory = TDEGlobal::dirs()->findResourceDir("duplicatebothhorz", "duplicatebothhorz.png");
        duplicateHorButton->setPixmap( TQPixmap( directory + "duplicatebothhorz.png" ) );
        duplicateHorButton->setToggleButton(true);
        TQWhatsThis::add( duplicateHorButton, i18n("<p>If you enable this option, you will separate the preview area "
@@ -163,8 +163,8 @@ ImagePannelWidget::ImagePannelWidget(uint w, uint h, const TQString& settingsSec
         
        TQPushButton *duplicateVerButton = new TQPushButton( d->separateView );
        d->separateView->insert(duplicateVerButton, ImageRegionWidget::SeparateViewDuplicateVert);
-       KGlobal::dirs()->addResourceType("duplicatebothvert", KGlobal::dirs()->kde_default("data") + "digikam/data");
-       directory = KGlobal::dirs()->findResourceDir("duplicatebothvert", "duplicatebothvert.png");
+       TDEGlobal::dirs()->addResourceType("duplicatebothvert", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+       directory = TDEGlobal::dirs()->findResourceDir("duplicatebothvert", "duplicatebothvert.png");
        duplicateVerButton->setPixmap( TQPixmap( directory + "duplicatebothvert.png" ) );
        duplicateVerButton->setToggleButton(true);
        TQWhatsThis::add( duplicateVerButton, i18n("<p>If you enable this option, you will separate the preview area "
@@ -178,8 +178,8 @@ ImagePannelWidget::ImagePannelWidget(uint w, uint h, const TQString& settingsSec
     {
        TQPushButton *separateHorButton = new TQPushButton( d->separateView );
        d->separateView->insert(separateHorButton, ImageRegionWidget::SeparateViewHorizontal);
-       KGlobal::dirs()->addResourceType("bothhorz", KGlobal::dirs()->kde_default("data") + "digikam/data");
-       directory = KGlobal::dirs()->findResourceDir("bothhorz", "bothhorz.png");
+       TDEGlobal::dirs()->addResourceType("bothhorz", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+       directory = TDEGlobal::dirs()->findResourceDir("bothhorz", "bothhorz.png");
        separateHorButton->setPixmap( TQPixmap( directory + "bothhorz.png" ) );
        separateHorButton->setToggleButton(true);
        TQWhatsThis::add( separateHorButton, i18n( "<p>If you enable this option, you will separate the preview area "
@@ -189,8 +189,8 @@ ImagePannelWidget::ImagePannelWidget(uint w, uint h, const TQString& settingsSec
         
        TQPushButton *separateVerButton = new TQPushButton( d->separateView );
        d->separateView->insert(separateVerButton, ImageRegionWidget::SeparateViewVertical);
-       KGlobal::dirs()->addResourceType("bothvert", KGlobal::dirs()->kde_default("data") + "digikam/data");
-       directory = KGlobal::dirs()->findResourceDir("bothvert", "bothvert.png");
+       TDEGlobal::dirs()->addResourceType("bothvert", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+       directory = TDEGlobal::dirs()->findResourceDir("bothvert", "bothvert.png");
        separateVerButton->setPixmap( TQPixmap( directory + "bothvert.png" ) );
        separateVerButton->setToggleButton(true);
        TQWhatsThis::add( separateVerButton, i18n( "<p>If you enable this option, you will separate the preview area "
@@ -201,8 +201,8 @@ ImagePannelWidget::ImagePannelWidget(uint w, uint h, const TQString& settingsSec
        
     TQPushButton *noSeparateButton = new TQPushButton( d->separateView );
     d->separateView->insert(noSeparateButton, ImageRegionWidget::SeparateViewNone);
-    KGlobal::dirs()->addResourceType("target", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("target", "target.png");
+    TDEGlobal::dirs()->addResourceType("target", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("target", "target.png");
     noSeparateButton->setPixmap( TQPixmap( directory + "target.png" ) );
     noSeparateButton->setToggleButton(true);
     TQWhatsThis::add( noSeparateButton, i18n( "<p>If you enable this option, the preview area will not "
@@ -291,7 +291,7 @@ ImagePannelWidget::~ImagePannelWidget()
 
 void ImagePannelWidget::readSettings()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(d->settingsSection);
     int mode = config->readNumEntry("Separate View", ImageRegionWidget::SeparateViewDuplicateVert);
     mode     = TQMAX(ImageRegionWidget::SeparateViewHorizontal, mode);
@@ -310,7 +310,7 @@ void ImagePannelWidget::readSettings()
     
 void ImagePannelWidget::writeSettings()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(d->settingsSection);
     config->writeEntry( "Separate View", d->separateView->selectedId() );
     config->sync();
