@@ -49,15 +49,15 @@
 #include <kseparator.h>
 #include <kcursor.h>
 #include <kurllabel.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kfiledialog.h>
+#include <tdeapplication.h>
+#include <tdefiledialog.h>
 #include <kstandarddirs.h>
 #include <kprogress.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 
 // LibKDcraw includes.
 
@@ -212,9 +212,9 @@ ImageResize::ImageResize(TQWidget* parent)
     d->cimgLogoLabel = new KURLLabel(firstPage);
     d->cimgLogoLabel->setText(TQString());
     d->cimgLogoLabel->setURL("http://cimg.sourceforge.net");
-    KGlobal::dirs()->addResourceType("logo-cimg", KGlobal::dirs()->kde_default("data") +
+    TDEGlobal::dirs()->addResourceType("logo-cimg", TDEGlobal::dirs()->kde_default("data") +
                                      "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("logo-cimg", "logo-cimg.png");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("logo-cimg", "logo-cimg.png");
     d->cimgLogoLabel->setPixmap( TQPixmap( directory + "logo-cimg.png" ) );
     TQToolTip::add(d->cimgLogoLabel, i18n("Visit CImg library website"));
 
@@ -303,7 +303,7 @@ void ImageResize::slotRestorationToggled(bool b)
 
 void ImageResize::readUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("resize Tool Dialog");
 
     GreycstorationSettings settings;
@@ -350,7 +350,7 @@ void ImageResize::readUserSettings()
 void ImageResize::writeUserSettings()
 {
     GreycstorationSettings settings = d->settingsWidget->getSettings();
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("resize Tool Dialog");
     config->writeEntry("FastApprox", settings.fastApprox);
     config->writeEntry("Interpolation", settings.interp);
@@ -482,7 +482,7 @@ void ImageResize::slotCancel()
 
 void ImageResize::processCImgURL(const TQString& url)
 {
-    KApplication::kApplication()->invokeBrowser(url);
+    TDEApplication::kApplication()->invokeBrowser(url);
 }
 
 void ImageResize::closeEvent(TQCloseEvent *e)
@@ -603,7 +603,7 @@ void ImageResize::customEvent(TQCustomEvent *event)
 
 void ImageResize::slotUser3()
 {
-    KURL loadBlowupFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadBlowupFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                        TQString( "*" ), this,
                                        TQString( i18n("Photograph Resizing Settings File to Load")) );
     if( loadBlowupFile.isEmpty() )
@@ -630,7 +630,7 @@ void ImageResize::slotUser3()
 
 void ImageResize::slotUser2()
 {
-    KURL saveBlowupFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveBlowupFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                        TQString( "*" ), this,
                                        TQString( i18n("Photograph Resizing Settings File to Save")) );
     if( saveBlowupFile.isEmpty() )
